/* addressBook.c was originally generated by the autoSql program, which also 
 * generated addressBook.h and addressBook.sql.  This module links the database and
 * the RAM representation of objects. */

#include "common.h"
#include "linefile.h"
#include "dystring.h"
#include "sqlList.h"
#include "sqlNum.h"
#include "addressBook.h"

void addressBookStaticLoad(char **row, struct addressBook *ret)
/* Load a row from addressBook table into ret.  The contents of ret will
 * be replaced at the next call to this function. */
{
int sizeOne,i;
char *s;

ret->name = row[0];
ret->address = row[1];
ret->city = row[2];
ret->zipCode = sqlUnsigned(row[3]);
strcpy(ret->state, row[4]);
}

struct addressBook *addressBookLoad(char **row)
/* Load a addressBook from row fetched with select * from addressBook
 * from database.  Dispose of this with addressBookFree(). */
{
struct addressBook *ret;
int sizeOne,i;
char *s;

AllocVar(ret);
ret->name = cloneString(row[0]);
ret->address = cloneString(row[1]);
ret->city = cloneString(row[2]);
ret->zipCode = sqlUnsigned(row[3]);
strcpy(ret->state, row[4]);
return ret;
}

struct addressBook *addressBookLoadAll(char *fileName) 
/* Load all addressBook from a tab-separated file.
 * Dispose of this with addressBookFreeList(). */
{
struct addressBook *list = NULL, *el;
struct lineFile *lf = lineFileOpen(fileName, TRUE);
char *row[5];

while (lineFileRow(lf, row))
    {
    el = addressBookLoad(row);
    slAddHead(&list, el);
    }
lineFileClose(&lf);
slReverse(&list);
return list;
}

struct addressBook *addressBookCommaIn(char **pS, struct addressBook *ret)
/* Create a addressBook out of a comma separated string. 
 * This will fill in ret if non-null, otherwise will
 * return a new addressBook */
{
char *s = *pS;
int i;

if (ret == NULL)
    AllocVar(ret);
ret->name = sqlStringComma(&s);
ret->address = sqlStringComma(&s);
ret->city = sqlStringComma(&s);
ret->zipCode = sqlUnsignedComma(&s);
sqlFixedStringComma(&s, ret->state, sizeof(ret->state));
*pS = s;
return ret;
}

void addressBookFree(struct addressBook **pEl)
/* Free a single dynamically allocated addressBook such as created
 * with addressBookLoad(). */
{
struct addressBook *el;

if ((el = *pEl) == NULL) return;
freeMem(el->name);
freeMem(el->address);
freeMem(el->city);
freez(pEl);
}

void addressBookFreeList(struct addressBook **pList)
/* Free a list of dynamically allocated addressBook's */
{
struct addressBook *el, *next;

for (el = *pList; el != NULL; el = next)
    {
    next = el->next;
    addressBookFree(&el);
    }
*pList = NULL;
}

void addressBookOutput(struct addressBook *el, FILE *f, char sep, char lastSep) 
/* Print out addressBook.  Separate fields with sep. Follow last field with lastSep. */
{
int i;
if (sep == ',') fputc('"',f);
fprintf(f, "%s", el->name);
if (sep == ',') fputc('"',f);
fputc(sep,f);
if (sep == ',') fputc('"',f);
fprintf(f, "%s", el->address);
if (sep == ',') fputc('"',f);
fputc(sep,f);
if (sep == ',') fputc('"',f);
fprintf(f, "%s", el->city);
if (sep == ',') fputc('"',f);
fputc(sep,f);
fprintf(f, "%u", el->zipCode);
fputc(sep,f);
if (sep == ',') fputc('"',f);
fprintf(f, "%s", el->state);
if (sep == ',') fputc('"',f);
fputc(lastSep,f);
}

